Is it cool that I said all that

{interactive slug="binary-cards" type="whole-page" parameters="digits=5&start=BBBBB" thumbnail="binarycards.png" text="true"}

{interactive slug="arrows" text="false" type="iframe" parameters="digits=5&start=BBBBB"}

{interactive end}

Is it too soon to do this yet
